Motion class

Constructors

Motion({int floorsDescended = 0, DateTime? endDate, int floorsAscended = 0, int numberOfSteps = 0, double distance = 0, DateTime? startDate, double averageActivePace = 0, double currentPace = 0})
const
Motion.fromJSON(Map<String, dynamic> data)
factory

Properties

averageActivePace → double
final
currentPace → double
final
distance → double
final
endDate → DateTime?
final
floorsAscended → int
final
floorsDescended → int
final
hashCode → int
The hash code for this object.
no setterinherited
numberOfSteps → int
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startDate → DateTime?
final
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
toJSON → Map<String, dynamic>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.

Operators

operator ==(Object other) → bool
The equality operator.
inherited